@@ -59,3 +59,11 @@ class Browser(object):
 	def get_text(self):
 		assert self.has_opened_url, "Browser has not opened a url yet."
 		return self.parser.unescape(self._browser.response().read())
+
+	def is_form_present(self, name):
+		assert self.has_opened_url, "Browser has not opened a url yet."
+		try:
+			self._browser.select_form(name=name)
+			return True
+		except mechanize.FormNotFoundError:
+			return False
