@@ -27,6 +27,10 @@ class TestBrowser(unittest.TestCase):
 		def has_example_link():
 			return "<a href='example.com'>example</a>"
 
+		@self.app.route('/form_present')
+		def form_present():
+			return '<form action=/hello_world name="foobar"></form>'
+
 	def test_instantiate(self):
 		""" Browser class can be instantiated without exploding.
 		"""
@@ -87,6 +91,13 @@ class TestBrowser(unittest.TestCase):
 		browser.open('/')
 		self.assertFalse(browser.is_link_present(url='example.com', text='example'))
 
+	def test_is_form_present(self):
+		"""Browser tests whether a form is present.
+		"""
+		browser = Browser(self.app)
+		browser.open('/form_present')
+		action='/hello_world'
+		self.assertTrue(browser.is_form_present(name='foobar'))
 
 if __name__ == '__main__':
 	unittest.main()
\ No newline at end of file
