@@ -14,3 +14,11 @@ class TestCaseMixin(object):
 			self.fail(
 				"Link with text=%s and url=%s not present in the page.\nResponse was:\n%s" %
 				(text, url, browser.get_text()))
+
+	def assertFormIsPresent(self, name, action=None, browser=None):
+		if not browser:
+			browser=self.browser
+		if not browser.is_form_present(name):
+			self.fail(
+				"Form with name='%s' and action='%s' not present in the page.\nResponse was:\n%s" % (
+					name, action, browser.get_text()))
\ No newline at end of file
